@@ -12,7 +12,7 @@ logger = logging.getLogger(__name__)
 
 
 class MailAuthBackend(ModelBackend):
-    signer = signing.UserSigner(sep='/')
+    signer = signing.UserSigner()
 
     def authenticate(self, request, token=None):
         max_age = getattr(settings, 'LOGIN_URL_TIMEOUT', 60 * 15)
@@ -28,7 +28,7 @@ class MailAuthBackend(ModelBackend):
         except SignatureExpired:
             logger.warning("Token has expired.", exc_info=True)
         except BadSignature:
-            logger.exception("Malicious or corrupted login token received.")
+            logger.exception('Malicious or corrupted login token received: "%s"', token)
         else:
             if self.user_can_authenticate(user):
                 return user
